Documentation
¶
Index ¶
- Variables
- func RegisterChatServiceServer(s grpc.ServiceRegistrar, srv ChatServiceServer)
- type ChatRequest
- type ChatResponse
- func (*ChatResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ChatResponse) GetCreatedAt() *timestamppb.Timestamp
- func (x *ChatResponse) GetId() string
- func (x *ChatResponse) GetMembers() []*User
- func (x *ChatResponse) GetMessages() []*Message
- func (x *ChatResponse) GetName() string
- func (x *ChatResponse) GetType() ChatType
- func (*ChatResponse) ProtoMessage()
- func (x *ChatResponse) ProtoReflect() protoreflect.Message
- func (x *ChatResponse) Reset()
- func (x *ChatResponse) String() string
- type ChatServiceClient
- type ChatServiceServer
- type ChatService_ChatStreamClient
- type ChatService_ChatStreamServer
- type ChatType
- type ChatsResponse
- type DirectChatAction
- func (*DirectChatAction) Descriptor() ([]byte, []int)deprecated
- func (x *DirectChatAction) GetAction() DirectChatAction_Action
- func (x *DirectChatAction) GetId() string
- func (*DirectChatAction) ProtoMessage()
- func (x *DirectChatAction) ProtoReflect() protoreflect.Message
- func (x *DirectChatAction) Reset()
- func (x *DirectChatAction) String() string
- type DirectChatAction_Action
- func (DirectChatAction_Action) Descriptor() protoreflect.EnumDescriptor
- func (x DirectChatAction_Action) Enum() *DirectChatAction_Action
- func (DirectChatAction_Action) EnumDescriptor() ([]byte, []int)deprecated
- func (x DirectChatAction_Action) Number() protoreflect.EnumNumber
- func (x DirectChatAction_Action) String() string
- func (DirectChatAction_Action) Type() protoreflect.EnumType
- type GroupChatRequest
- func (*GroupChatRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GroupChatRequest) GetGroupName() string
- func (x *GroupChatRequest) GetGroupPasskey() string
- func (*GroupChatRequest) ProtoMessage()
- func (x *GroupChatRequest) ProtoReflect() protoreflect.Message
- func (x *GroupChatRequest) Reset()
- func (x *GroupChatRequest) String() string
- type JoinDirectChatRequest
- func (*JoinDirectChatRequest) Descriptor() ([]byte, []int)deprecated
- func (x *JoinDirectChatRequest) GetReceiver() *User
- func (x *JoinDirectChatRequest) GetSentAt() *timestamppb.Timestamp
- func (*JoinDirectChatRequest) ProtoMessage()
- func (x *JoinDirectChatRequest) ProtoReflect() protoreflect.Message
- func (x *JoinDirectChatRequest) Reset()
- func (x *JoinDirectChatRequest) String() string
- type JoinDirectChatResponse
- func (*JoinDirectChatResponse) Descriptor() ([]byte, []int)deprecated
- func (x *JoinDirectChatResponse) GetId() string
- func (x *JoinDirectChatResponse) GetSender() *User
- func (*JoinDirectChatResponse) ProtoMessage()
- func (x *JoinDirectChatResponse) ProtoReflect() protoreflect.Message
- func (x *JoinDirectChatResponse) Reset()
- func (x *JoinDirectChatResponse) String() string
- type JoinDirectChatResponses
- func (*JoinDirectChatResponses) Descriptor() ([]byte, []int)deprecated
- func (x *JoinDirectChatResponses) GetRequests() []*JoinDirectChatResponse
- func (*JoinDirectChatResponses) ProtoMessage()
- func (x *JoinDirectChatResponses) ProtoReflect() protoreflect.Message
- func (x *JoinDirectChatResponses) Reset()
- func (x *JoinDirectChatResponses) String() string
- type Message
- func (*Message) Descriptor() ([]byte, []int)deprecated
- func (x *Message) GetContent() string
- func (x *Message) GetId() string
- func (x *Message) GetSender() *User
- func (x *Message) GetSentAt() *timestamppb.Timestamp
- func (x *Message) GetType() Message_MessageType
- func (*Message) ProtoMessage()
- func (x *Message) ProtoReflect() protoreflect.Message
- func (x *Message) Reset()
- func (x *Message) String() string
- type MessageStream
- func (*MessageStream) Descriptor() ([]byte, []int)deprecated
- func (x *MessageStream) GetChatId() string
- func (x *MessageStream) GetMessage() *Message
- func (*MessageStream) ProtoMessage()
- func (x *MessageStream) ProtoReflect() protoreflect.Message
- func (x *MessageStream) Reset()
- func (x *MessageStream) String() string
- type Message_MessageType
- func (Message_MessageType) Descriptor() protoreflect.EnumDescriptor
- func (x Message_MessageType) Enum() *Message_MessageType
- func (Message_MessageType) EnumDescriptor() ([]byte, []int)deprecated
- func (x Message_MessageType) Number() protoreflect.EnumNumber
- func (x Message_MessageType) String() string
- func (Message_MessageType) Type() protoreflect.EnumType
- type UnimplementedChatServiceServer
- func (UnimplementedChatServiceServer) ChatStream(ChatService_ChatStreamServer) error
- func (UnimplementedChatServiceServer) CreateGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
- func (UnimplementedChatServiceServer) CreateNewAccount(context.Context, *UserRequest) (*UserCreatedResponse, error)
- func (UnimplementedChatServiceServer) DirectChatRequestAction(context.Context, *DirectChatAction) (*emptypb.Empty, error)
- func (UnimplementedChatServiceServer) GetChats(context.Context, *emptypb.Empty) (*ChatsResponse, error)
- func (UnimplementedChatServiceServer) GetDirectChatRequests(context.Context, *emptypb.Empty) (*JoinDirectChatResponses, error)
- func (UnimplementedChatServiceServer) JoinDirectChat(context.Context, *JoinDirectChatRequest) (*JoinDirectChatResponse, error)
- func (UnimplementedChatServiceServer) JoinGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
- func (UnimplementedChatServiceServer) LogIntoAccount(context.Context, *UserRequest) (*UserAuthenticatedResponse, error)
- type UnsafeChatServiceServer
- type User
- type UserAuthenticatedResponse
- func (*UserAuthenticatedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UserAuthenticatedResponse) GetToken() string
- func (x *UserAuthenticatedResponse) GetUser() *User
- func (*UserAuthenticatedResponse) ProtoMessage()
- func (x *UserAuthenticatedResponse) ProtoReflect() protoreflect.Message
- func (x *UserAuthenticatedResponse) Reset()
- func (x *UserAuthenticatedResponse) String() string
- type UserCreatedResponse
- func (*UserCreatedResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UserCreatedResponse) GetUser() string
- func (*UserCreatedResponse) ProtoMessage()
- func (x *UserCreatedResponse) ProtoReflect() protoreflect.Message
- func (x *UserCreatedResponse) Reset()
- func (x *UserCreatedResponse) String() string
- type UserRequest
- func (*UserRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UserRequest) GetPassword() string
- func (x *UserRequest) GetUsername() string
- func (*UserRequest) ProtoMessage()
- func (x *UserRequest) ProtoReflect() protoreflect.Message
- func (x *UserRequest) Reset()
- func (x *UserRequest) String() string
Constants ¶
This section is empty.
Variables ¶
var ( ChatType_name = map[int32]string{ 0: "CHAT_TYPE_UNSPECIFIED", 1: "CHAT_TYPE_DIRECT", 2: "CHAT_TYPE_GROUP", } ChatType_value = map[string]int32{ "CHAT_TYPE_UNSPECIFIED": 0, "CHAT_TYPE_DIRECT": 1, "CHAT_TYPE_GROUP": 2, } )
Enum value maps for ChatType.
var ( DirectChatAction_Action_name = map[int32]string{ 0: "ACTION_UNSPECIFIED", 1: "ACTION_ACCEPT", 2: "ACTION_REJECT", } DirectChatAction_Action_value = map[string]int32{ "ACTION_UNSPECIFIED": 0, "ACTION_ACCEPT": 1, "ACTION_REJECT": 2, } )
Enum value maps for DirectChatAction_Action.
var ( Message_MessageType_name = map[int32]string{ 0: "MESSAGE_TYPE_UNSPECIFIED", 1: "MESSAGE_TYPE_NOTIFICATION", 2: "MESSAGE_TYPE_REGULAR", } Message_MessageType_value = map[string]int32{ "MESSAGE_TYPE_UNSPECIFIED": 0, "MESSAGE_TYPE_NOTIFICATION": 1, "MESSAGE_TYPE_REGULAR": 2, } )
Enum value maps for Message_MessageType.
var ChatService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "chat.ChatService", HandlerType: (*ChatServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateNewAccount", Handler: _ChatService_CreateNewAccount_Handler, }, { MethodName: "LogIntoAccount", Handler: _ChatService_LogIntoAccount_Handler, }, { MethodName: "JoinDirectChat", Handler: _ChatService_JoinDirectChat_Handler, }, { MethodName: "JoinGroupChat", Handler: _ChatService_JoinGroupChat_Handler, }, { MethodName: "GetDirectChatRequests", Handler: _ChatService_GetDirectChatRequests_Handler, }, { MethodName: "GetChats", Handler: _ChatService_GetChats_Handler, }, { MethodName: "CreateGroupChat", Handler: _ChatService_CreateGroupChat_Handler, }, { MethodName: "DirectChatRequestAction", Handler: _ChatService_DirectChatRequestAction_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "ChatStream", Handler: _ChatService_ChatStream_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "chat_service.proto", }
ChatService_ServiceDesc is the grpc.ServiceDesc for ChatService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_auth_message_proto protoreflect.FileDescriptor
var File_chat_message_proto protoreflect.FileDescriptor
var File_chat_service_proto protoreflect.FileDescriptor
var File_message_message_proto protoreflect.FileDescriptor
var File_user_message_proto protoreflect.FileDescriptor
Functions ¶
func RegisterChatServiceServer ¶
func RegisterChatServiceServer(s grpc.ServiceRegistrar, srv ChatServiceServer)
Types ¶
type ChatRequest ¶
type ChatRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Chat ChatType `protobuf:"varint,2,opt,name=chat,proto3,enum=chat.ChatType" json:"chat,omitempty"`
// contains filtered or unexported fields
}
func (*ChatRequest) Descriptor
deprecated
func (*ChatRequest) Descriptor() ([]byte, []int)
Deprecated: Use ChatRequest.ProtoReflect.Descriptor instead.
func (*ChatRequest) GetChat ¶
func (x *ChatRequest) GetChat() ChatType
func (*ChatRequest) GetId ¶
func (x *ChatRequest) GetId() string
func (*ChatRequest) ProtoMessage ¶
func (*ChatRequest) ProtoMessage()
func (*ChatRequest) ProtoReflect ¶
func (x *ChatRequest) ProtoReflect() protoreflect.Message
func (*ChatRequest) Reset ¶
func (x *ChatRequest) Reset()
func (*ChatRequest) String ¶
func (x *ChatRequest) String() string
type ChatResponse ¶
type ChatResponse struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Messages []*Message `protobuf:"bytes,2,rep,name=messages,proto3" json:"messages,omitempty"`
Members []*User `protobuf:"bytes,3,rep,name=members,proto3" json:"members,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
Type ChatType `protobuf:"varint,5,opt,name=type,proto3,enum=chat.ChatType" json:"type,omitempty"`
Name *string `protobuf:"bytes,6,opt,name=name,proto3,oneof" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*ChatResponse) Descriptor
deprecated
func (*ChatResponse) Descriptor() ([]byte, []int)
Deprecated: Use ChatResponse.ProtoReflect.Descriptor instead.
func (*ChatResponse) GetCreatedAt ¶
func (x *ChatResponse) GetCreatedAt() *timestamppb.Timestamp
func (*ChatResponse) GetId ¶
func (x *ChatResponse) GetId() string
func (*ChatResponse) GetMembers ¶
func (x *ChatResponse) GetMembers() []*User
func (*ChatResponse) GetMessages ¶
func (x *ChatResponse) GetMessages() []*Message
func (*ChatResponse) GetName ¶
func (x *ChatResponse) GetName() string
func (*ChatResponse) GetType ¶
func (x *ChatResponse) GetType() ChatType
func (*ChatResponse) ProtoMessage ¶
func (*ChatResponse) ProtoMessage()
func (*ChatResponse) ProtoReflect ¶
func (x *ChatResponse) ProtoReflect() protoreflect.Message
func (*ChatResponse) Reset ¶
func (x *ChatResponse) Reset()
func (*ChatResponse) String ¶
func (x *ChatResponse) String() string
type ChatServiceClient ¶
type ChatServiceClient interface {
CreateNewAccount(ctx context.Context, in *UserRequest, opts ...grpc.CallOption) (*UserCreatedResponse, error)
LogIntoAccount(ctx context.Context, in *UserRequest, opts ...grpc.CallOption) (*UserAuthenticatedResponse, error)
ChatStream(ctx context.Context, opts ...grpc.CallOption) (ChatService_ChatStreamClient, error)
JoinDirectChat(ctx context.Context, in *JoinDirectChatRequest, opts ...grpc.CallOption) (*JoinDirectChatResponse, error)
JoinGroupChat(ctx context.Context, in *GroupChatRequest, opts ...grpc.CallOption) (*ChatResponse, error)
GetDirectChatRequests(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*JoinDirectChatResponses, error)
GetChats(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*ChatsResponse, error)
CreateGroupChat(ctx context.Context, in *GroupChatRequest, opts ...grpc.CallOption) (*ChatResponse, error)
DirectChatRequestAction(ctx context.Context, in *DirectChatAction, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
ChatServiceClient is the client API for ChatService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewChatServiceClient ¶
func NewChatServiceClient(cc grpc.ClientConnInterface) ChatServiceClient
type ChatServiceServer ¶
type ChatServiceServer interface {
CreateNewAccount(context.Context, *UserRequest) (*UserCreatedResponse, error)
LogIntoAccount(context.Context, *UserRequest) (*UserAuthenticatedResponse, error)
ChatStream(ChatService_ChatStreamServer) error
JoinDirectChat(context.Context, *JoinDirectChatRequest) (*JoinDirectChatResponse, error)
JoinGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
GetDirectChatRequests(context.Context, *emptypb.Empty) (*JoinDirectChatResponses, error)
GetChats(context.Context, *emptypb.Empty) (*ChatsResponse, error)
CreateGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
DirectChatRequestAction(context.Context, *DirectChatAction) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
ChatServiceServer is the server API for ChatService service. All implementations must embed UnimplementedChatServiceServer for forward compatibility
type ChatService_ChatStreamClient ¶
type ChatService_ChatStreamClient interface {
Send(*MessageStream) error
Recv() (*MessageStream, error)
grpc.ClientStream
}
type ChatService_ChatStreamServer ¶
type ChatService_ChatStreamServer interface {
Send(*MessageStream) error
Recv() (*MessageStream, error)
grpc.ServerStream
}
type ChatType ¶
type ChatType int32
func (ChatType) Descriptor ¶
func (ChatType) Descriptor() protoreflect.EnumDescriptor
func (ChatType) EnumDescriptor
deprecated
func (ChatType) Number ¶
func (x ChatType) Number() protoreflect.EnumNumber
func (ChatType) Type ¶
func (ChatType) Type() protoreflect.EnumType
type ChatsResponse ¶
type ChatsResponse struct {
Chats []*ChatResponse `protobuf:"bytes,1,rep,name=chats,proto3" json:"chats,omitempty"`
// contains filtered or unexported fields
}
func (*ChatsResponse) Descriptor
deprecated
func (*ChatsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ChatsResponse.ProtoReflect.Descriptor instead.
func (*ChatsResponse) GetChats ¶
func (x *ChatsResponse) GetChats() []*ChatResponse
func (*ChatsResponse) ProtoMessage ¶
func (*ChatsResponse) ProtoMessage()
func (*ChatsResponse) ProtoReflect ¶
func (x *ChatsResponse) ProtoReflect() protoreflect.Message
func (*ChatsResponse) Reset ¶
func (x *ChatsResponse) Reset()
func (*ChatsResponse) String ¶
func (x *ChatsResponse) String() string
type DirectChatAction ¶
type DirectChatAction struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Action DirectChatAction_Action `protobuf:"varint,2,opt,name=action,proto3,enum=chat.DirectChatAction_Action" json:"action,omitempty"`
// contains filtered or unexported fields
}
func (*DirectChatAction) Descriptor
deprecated
func (*DirectChatAction) Descriptor() ([]byte, []int)
Deprecated: Use DirectChatAction.ProtoReflect.Descriptor instead.
func (*DirectChatAction) GetAction ¶
func (x *DirectChatAction) GetAction() DirectChatAction_Action
func (*DirectChatAction) GetId ¶
func (x *DirectChatAction) GetId() string
func (*DirectChatAction) ProtoMessage ¶
func (*DirectChatAction) ProtoMessage()
func (*DirectChatAction) ProtoReflect ¶
func (x *DirectChatAction) ProtoReflect() protoreflect.Message
func (*DirectChatAction) Reset ¶
func (x *DirectChatAction) Reset()
func (*DirectChatAction) String ¶
func (x *DirectChatAction) String() string
type DirectChatAction_Action ¶
type DirectChatAction_Action int32
const ( DirectChatAction_ACTION_UNSPECIFIED DirectChatAction_Action = 0 DirectChatAction_ACTION_ACCEPT DirectChatAction_Action = 1 DirectChatAction_ACTION_REJECT DirectChatAction_Action = 2 )
func (DirectChatAction_Action) Descriptor ¶
func (DirectChatAction_Action) Descriptor() protoreflect.EnumDescriptor
func (DirectChatAction_Action) Enum ¶
func (x DirectChatAction_Action) Enum() *DirectChatAction_Action
func (DirectChatAction_Action) EnumDescriptor
deprecated
func (DirectChatAction_Action) EnumDescriptor() ([]byte, []int)
Deprecated: Use DirectChatAction_Action.Descriptor instead.
func (DirectChatAction_Action) Number ¶
func (x DirectChatAction_Action) Number() protoreflect.EnumNumber
func (DirectChatAction_Action) String ¶
func (x DirectChatAction_Action) String() string
func (DirectChatAction_Action) Type ¶
func (DirectChatAction_Action) Type() protoreflect.EnumType
type GroupChatRequest ¶
type GroupChatRequest struct {
GroupName string `protobuf:"bytes,1,opt,name=group_name,json=groupName,proto3" json:"group_name,omitempty"`
GroupPasskey string `protobuf:"bytes,2,opt,name=group_passkey,json=groupPasskey,proto3" json:"group_passkey,omitempty"`
// contains filtered or unexported fields
}
func (*GroupChatRequest) Descriptor
deprecated
func (*GroupChatRequest) Descriptor() ([]byte, []int)
Deprecated: Use GroupChatRequest.ProtoReflect.Descriptor instead.
func (*GroupChatRequest) GetGroupName ¶
func (x *GroupChatRequest) GetGroupName() string
func (*GroupChatRequest) GetGroupPasskey ¶
func (x *GroupChatRequest) GetGroupPasskey() string
func (*GroupChatRequest) ProtoMessage ¶
func (*GroupChatRequest) ProtoMessage()
func (*GroupChatRequest) ProtoReflect ¶
func (x *GroupChatRequest) ProtoReflect() protoreflect.Message
func (*GroupChatRequest) Reset ¶
func (x *GroupChatRequest) Reset()
func (*GroupChatRequest) String ¶
func (x *GroupChatRequest) String() string
type JoinDirectChatRequest ¶
type JoinDirectChatRequest struct {
Receiver *User `protobuf:"bytes,1,opt,name=receiver,proto3" json:"receiver,omitempty"`
SentAt *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=sent_at,json=sentAt,proto3" json:"sent_at,omitempty"`
// contains filtered or unexported fields
}
func (*JoinDirectChatRequest) Descriptor
deprecated
func (*JoinDirectChatRequest) Descriptor() ([]byte, []int)
Deprecated: Use JoinDirectChatRequest.ProtoReflect.Descriptor instead.
func (*JoinDirectChatRequest) GetReceiver ¶
func (x *JoinDirectChatRequest) GetReceiver() *User
func (*JoinDirectChatRequest) GetSentAt ¶
func (x *JoinDirectChatRequest) GetSentAt() *timestamppb.Timestamp
func (*JoinDirectChatRequest) ProtoMessage ¶
func (*JoinDirectChatRequest) ProtoMessage()
func (*JoinDirectChatRequest) ProtoReflect ¶
func (x *JoinDirectChatRequest) ProtoReflect() protoreflect.Message
func (*JoinDirectChatRequest) Reset ¶
func (x *JoinDirectChatRequest) Reset()
func (*JoinDirectChatRequest) String ¶
func (x *JoinDirectChatRequest) String() string
type JoinDirectChatResponse ¶
type JoinDirectChatResponse struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Sender *User `protobuf:"bytes,2,opt,name=sender,proto3" json:"sender,omitempty"`
// contains filtered or unexported fields
}
func (*JoinDirectChatResponse) Descriptor
deprecated
func (*JoinDirectChatResponse) Descriptor() ([]byte, []int)
Deprecated: Use JoinDirectChatResponse.ProtoReflect.Descriptor instead.
func (*JoinDirectChatResponse) GetId ¶
func (x *JoinDirectChatResponse) GetId() string
func (*JoinDirectChatResponse) GetSender ¶
func (x *JoinDirectChatResponse) GetSender() *User
func (*JoinDirectChatResponse) ProtoMessage ¶
func (*JoinDirectChatResponse) ProtoMessage()
func (*JoinDirectChatResponse) ProtoReflect ¶
func (x *JoinDirectChatResponse) ProtoReflect() protoreflect.Message
func (*JoinDirectChatResponse) Reset ¶
func (x *JoinDirectChatResponse) Reset()
func (*JoinDirectChatResponse) String ¶
func (x *JoinDirectChatResponse) String() string
type JoinDirectChatResponses ¶
type JoinDirectChatResponses struct {
Requests []*JoinDirectChatResponse `protobuf:"bytes,1,rep,name=requests,proto3" json:"requests,omitempty"`
// contains filtered or unexported fields
}
func (*JoinDirectChatResponses) Descriptor
deprecated
func (*JoinDirectChatResponses) Descriptor() ([]byte, []int)
Deprecated: Use JoinDirectChatResponses.ProtoReflect.Descriptor instead.
func (*JoinDirectChatResponses) GetRequests ¶
func (x *JoinDirectChatResponses) GetRequests() []*JoinDirectChatResponse
func (*JoinDirectChatResponses) ProtoMessage ¶
func (*JoinDirectChatResponses) ProtoMessage()
func (*JoinDirectChatResponses) ProtoReflect ¶
func (x *JoinDirectChatResponses) ProtoReflect() protoreflect.Message
func (*JoinDirectChatResponses) Reset ¶
func (x *JoinDirectChatResponses) Reset()
func (*JoinDirectChatResponses) String ¶
func (x *JoinDirectChatResponses) String() string
type Message ¶
type Message struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Sender *User `protobuf:"bytes,2,opt,name=sender,proto3,oneof" json:"sender,omitempty"`
Type Message_MessageType `protobuf:"varint,3,opt,name=type,proto3,enum=chat.Message_MessageType" json:"type,omitempty"`
Content string `protobuf:"bytes,4,opt,name=content,proto3" json:"content,omitempty"`
SentAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=sent_at,json=sentAt,proto3" json:"sent_at,omitempty"`
// contains filtered or unexported fields
}
func (*Message) Descriptor
deprecated
func (*Message) GetContent ¶
func (*Message) GetSentAt ¶
func (x *Message) GetSentAt() *timestamppb.Timestamp
func (*Message) GetType ¶
func (x *Message) GetType() Message_MessageType
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) ProtoReflect ¶
func (x *Message) ProtoReflect() protoreflect.Message
type MessageStream ¶
type MessageStream struct {
ChatId string `protobuf:"bytes,1,opt,name=chat_id,json=chatId,proto3" json:"chat_id,omitempty"`
Message *Message `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*MessageStream) Descriptor
deprecated
func (*MessageStream) Descriptor() ([]byte, []int)
Deprecated: Use MessageStream.ProtoReflect.Descriptor instead.
func (*MessageStream) GetChatId ¶
func (x *MessageStream) GetChatId() string
func (*MessageStream) GetMessage ¶
func (x *MessageStream) GetMessage() *Message
func (*MessageStream) ProtoMessage ¶
func (*MessageStream) ProtoMessage()
func (*MessageStream) ProtoReflect ¶
func (x *MessageStream) ProtoReflect() protoreflect.Message
func (*MessageStream) Reset ¶
func (x *MessageStream) Reset()
func (*MessageStream) String ¶
func (x *MessageStream) String() string
type Message_MessageType ¶
type Message_MessageType int32
const ( Message_MESSAGE_TYPE_UNSPECIFIED Message_MessageType = 0 Message_MESSAGE_TYPE_NOTIFICATION Message_MessageType = 1 Message_MESSAGE_TYPE_REGULAR Message_MessageType = 2 )
func (Message_MessageType) Descriptor ¶
func (Message_MessageType) Descriptor() protoreflect.EnumDescriptor
func (Message_MessageType) Enum ¶
func (x Message_MessageType) Enum() *Message_MessageType
func (Message_MessageType) EnumDescriptor
deprecated
func (Message_MessageType) EnumDescriptor() ([]byte, []int)
Deprecated: Use Message_MessageType.Descriptor instead.
func (Message_MessageType) Number ¶
func (x Message_MessageType) Number() protoreflect.EnumNumber
func (Message_MessageType) String ¶
func (x Message_MessageType) String() string
func (Message_MessageType) Type ¶
func (Message_MessageType) Type() protoreflect.EnumType
type UnimplementedChatServiceServer ¶
type UnimplementedChatServiceServer struct {
}
UnimplementedChatServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedChatServiceServer) ChatStream ¶
func (UnimplementedChatServiceServer) ChatStream(ChatService_ChatStreamServer) error
func (UnimplementedChatServiceServer) CreateGroupChat ¶
func (UnimplementedChatServiceServer) CreateGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
func (UnimplementedChatServiceServer) CreateNewAccount ¶
func (UnimplementedChatServiceServer) CreateNewAccount(context.Context, *UserRequest) (*UserCreatedResponse, error)
func (UnimplementedChatServiceServer) DirectChatRequestAction ¶
func (UnimplementedChatServiceServer) DirectChatRequestAction(context.Context, *DirectChatAction) (*emptypb.Empty, error)
func (UnimplementedChatServiceServer) GetChats ¶
func (UnimplementedChatServiceServer) GetChats(context.Context, *emptypb.Empty) (*ChatsResponse, error)
func (UnimplementedChatServiceServer) GetDirectChatRequests ¶
func (UnimplementedChatServiceServer) GetDirectChatRequests(context.Context, *emptypb.Empty) (*JoinDirectChatResponses, error)
func (UnimplementedChatServiceServer) JoinDirectChat ¶
func (UnimplementedChatServiceServer) JoinDirectChat(context.Context, *JoinDirectChatRequest) (*JoinDirectChatResponse, error)
func (UnimplementedChatServiceServer) JoinGroupChat ¶
func (UnimplementedChatServiceServer) JoinGroupChat(context.Context, *GroupChatRequest) (*ChatResponse, error)
func (UnimplementedChatServiceServer) LogIntoAccount ¶
func (UnimplementedChatServiceServer) LogIntoAccount(context.Context, *UserRequest) (*UserAuthenticatedResponse, error)
type UnsafeChatServiceServer ¶
type UnsafeChatServiceServer interface {
// contains filtered or unexported methods
}
UnsafeChatServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ChatServiceServer will result in compilation errors.
type User ¶
type User struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Id string `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*User) Descriptor
deprecated
func (*User) GetUsername ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
type UserAuthenticatedResponse ¶
type UserAuthenticatedResponse struct {
User *User `protobuf:"bytes,2,opt,name=user,proto3" json:"user,omitempty"`
Token string `protobuf:"bytes,3,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
func (*UserAuthenticatedResponse) Descriptor
deprecated
func (*UserAuthenticatedResponse) Descriptor() ([]byte, []int)
Deprecated: Use UserAuthenticatedResponse.ProtoReflect.Descriptor instead.
func (*UserAuthenticatedResponse) GetToken ¶
func (x *UserAuthenticatedResponse) GetToken() string
func (*UserAuthenticatedResponse) GetUser ¶
func (x *UserAuthenticatedResponse) GetUser() *User
func (*UserAuthenticatedResponse) ProtoMessage ¶
func (*UserAuthenticatedResponse) ProtoMessage()
func (*UserAuthenticatedResponse) ProtoReflect ¶
func (x *UserAuthenticatedResponse) ProtoReflect() protoreflect.Message
func (*UserAuthenticatedResponse) Reset ¶
func (x *UserAuthenticatedResponse) Reset()
func (*UserAuthenticatedResponse) String ¶
func (x *UserAuthenticatedResponse) String() string
type UserCreatedResponse ¶
type UserCreatedResponse struct {
User string `protobuf:"bytes,2,opt,name=user,proto3" json:"user,omitempty"`
// contains filtered or unexported fields
}
func (*UserCreatedResponse) Descriptor
deprecated
func (*UserCreatedResponse) Descriptor() ([]byte, []int)
Deprecated: Use UserCreatedResponse.ProtoReflect.Descriptor instead.
func (*UserCreatedResponse) GetUser ¶
func (x *UserCreatedResponse) GetUser() string
func (*UserCreatedResponse) ProtoMessage ¶
func (*UserCreatedResponse) ProtoMessage()
func (*UserCreatedResponse) ProtoReflect ¶
func (x *UserCreatedResponse) ProtoReflect() protoreflect.Message
func (*UserCreatedResponse) Reset ¶
func (x *UserCreatedResponse) Reset()
func (*UserCreatedResponse) String ¶
func (x *UserCreatedResponse) String() string
type UserRequest ¶
type UserRequest struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*UserRequest) Descriptor
deprecated
func (*UserRequest) Descriptor() ([]byte, []int)
Deprecated: Use UserRequest.ProtoReflect.Descriptor instead.
func (*UserRequest) GetPassword ¶
func (x *UserRequest) GetPassword() string
func (*UserRequest) GetUsername ¶
func (x *UserRequest) GetUsername() string
func (*UserRequest) ProtoMessage ¶
func (*UserRequest) ProtoMessage()
func (*UserRequest) ProtoReflect ¶
func (x *UserRequest) ProtoReflect() protoreflect.Message
func (*UserRequest) Reset ¶
func (x *UserRequest) Reset()
func (*UserRequest) String ¶
func (x *UserRequest) String() string